OC.L10N.register(
    "settings",
    {
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Güvenlik ve kurulum uyarıları",
    "Sharing" : "Paylaşım",
    "Server-side encryption" : "Sunucu taraflı şifreleme",
    "External Storage" : "Harici Depolama",
    "Cron" : "Cron",
    "Email server" : "E-posta sunucusu",
    "Log" : "Günlük",
    "Server Status" : "Sunucu Durumu",
    "Tips & tricks" : "İpuçları ve hileler",
    "Updates" : "Güncellemeler",
    "Authentication error" : "Kimlik doğrulama hatası",
    "Your full name has been changed." : "Tam adınız değiştirildi.",
    "Unable to change full name" : "Tam adınız değiştirilirken hata",
    "Couldn't remove app." : "Uygulama kaldırılamadı.",
    "Language changed" : "Dil değiştirildi",
    "Invalid request" : "Geçersiz istek",
    "Admins can't remove themself from the admin group" : "Yöneticiler kendilerini admin grubundan kaldıramaz",
    "Unable to add user to group %s" : "Kullanıcı %s grubuna eklenemiyor",
    "Unable to remove user from group %s" : "%s grubundan kullanıcı kaldırılamıyor",
    "Couldn't update app." : "Uygulama güncellenemedi.",
    "Wrong password" : "Hatalı parola",
    "No user supplied" : "Kullanıcı girilmedi",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Lütfen yönetici kurtarma parolasını girin, aksi takdirde tüm kullanıcı verisi kaybedilecek",
    "Wrong admin recovery password. Please check the password and try again." : "Hatalı yönetici kurtarma parolası. Lütfen parolayı denetleyip yeniden deneyin.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Arka uç, parola değiştirmesini desteklemiyor, ancak kullanıcı şifreleme anahtarı başarıyla güncellendi.",
    "Unable to change password" : "Parola değiştirilemiyor",
    "Enabled" : "Etkin",
    "Not enabled" : "Etkin değil",
    "A problem occurred, please check your log files (Error: %s)" : "Bir problem oluştu, lütfen log dosyalarını kontrol edin (Hata: %s)",
    "Migration Completed" : "Taşınma Tamamlandı",
    "Group already exists." : "Grup zaten mevcut.",
    "Unable to add group." : "Grup ekleme başarısız.",
    "Unable to delete group." : "Grubu silme başarısız.",
    "log-level out of allowed range" : "günlük seviyesi izin verilen aralık dışında",
    "Saved" : "Kaydedildi",
    "test email settings" : "e-posta ayarlarını sına",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-posta gönderilirken bir hata oluştu. Lütfen ayarlarınızı gözden geçirin. (Hata: %s)",
    "Email sent" : "E-posta gönderildi",
    "You need to set your user email before being able to send test emails." : "Sınama e-postaları göndermeden önce kullanıcı e-postasını ayarlamanız gerekiyor.",
    "Invalid mail address" : "Geçersiz posta adresi",
    "A user with that name already exists." : "Bu isimde bir kullanıcı adı zaten mevcut.",
    "Unable to create user." : "Kullanıcı oluşturma başarısız.",
    "Your %s account was created" : "%s hesabınız oluşturuldu",
    "Unable to delete user." : "Kullanıcı silme başarısız.",
    "Forbidden" : "Yasaklı",
    "Invalid user" : "Geçersiz kullanıcı",
    "Unable to change mail address" : "Posta adresini değiştirme başarısız",
    "Email saved" : "E-posta kaydedildi",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "\"{domain}\" alan adını güvenilir alan adı olarak eklemek istediğinizden emin misiniz?",
    "Add trusted domain" : "Güvenilir alan adı ekle",
    "Migration in progress. Please wait until the migration is finished" : "Taşınma sürüyor. Lütfen taşınma tamamlanana kadar bekleyin",
    "Migration started …" : "Taşınma başladı ...",
    "Sending..." : "Gönderiliyor...",
    "Official" : "Resmi",
    "Approved" : "Onaylanmış",
    "Experimental" : "Deneysel",
    "All" : "Tümü",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Resmi uygulamalar ownCloud topluluğu tarafından geliştirilir. ownCloud'a işlevsellik merkezli olarak hazırlanırlar ve günlük kullanıma hazırdırlar.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Onaylanan uygulamalar güvenilir geliştiriciler tarafından geliştirilir ve detaylı olmayan bir güvenlik kontrolünden geçirilir. Bunlar açık kaynak kod deposunda bulunmakta ve normal kullanım için kararlı oldukları varsayılmaktadır.",
    "Update to %s" : "%s sürümüne güncelle",
    "Please wait...." : "Lütfen bekleyin....",
    "Error while disabling app" : "Uygulama devre dışı bırakılırken hata",
    "Disable" : "Devre Dışı Bırak",
    "Enable" : "Etkinleştir",
    "Error while enabling app" : "Uygulama etkinleştirilirken hata",
    "Updating...." : "Güncelleniyor....",
    "Error while updating app" : "Uygulama güncellenirken hata",
    "Updated" : "Güncellendi",
    "Uninstalling ...." : "Kaldırılıyor ....",
    "Error while uninstalling app" : "Uygulama kaldırılırken hata",
    "Uninstall" : "Kaldır",
    "Select a profile picture" : "Bir profil fotoğrafı seçin",
    "Very weak password" : "Çok güçsüz parola",
    "Weak password" : "Güçsüz parola",
    "So-so password" : "Normal parola",
    "Good password" : "İyi parola",
    "Strong password" : "Güçlü parola",
    "Valid until {date}" : "{date} tarihine kadar geçerli",
    "Delete" : "Sil",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Bir hata oluştu. Lütfen ASCII-kodlanmış PEM sertifikasını yükleyin.",
    "Groups" : "Gruplar",
    "Unable to delete {objName}" : "{objName} silinemiyor",
    "Error creating group" : "Grup oluşturulurken hata",
    "A valid group name must be provided" : "Geçerli bir grup adı mutlaka sağlanmalı",
    "deleted {groupName}" : "{groupName} silindi",
    "undo" : "geri al",
    "no group" : "grup yok",
    "never" : "hiçbir zaman",
    "deleted {userName}" : "{userName} silindi",
    "add group" : "grup ekle",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Parolayı değiştirmek, bu kullanıcı için veri kurtarması kullanılamadığından veri kaybına sebep olacak",
    "A valid username must be provided" : "Geçerli bir kullanıcı adı mutlaka sağlanmalı",
    "Error creating user" : "Kullanıcı oluşturulurken hata",
    "A valid password must be provided" : "Geçerli bir parola mutlaka sağlanmalı",
    "A valid email must be provided" : "Geçerli bir e-posta belirtilmeli",
    "__language_name__" : "Türkçe",
    "Sync clients" : "Eşitleme istemcileri",
    "Personal info" : "Kişisel bilgi",
    "SSL root certificates" : "SSL kök sertifikaları",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Her şey (Ciddi sorunlar, hatalar, uyarılar, bilgi, hata ayıklama)",
    "Info, warnings, errors and fatal issues" : "Bilgi, uyarılar, hatalar ve ciddi sorunlar",
    "Warnings, errors and fatal issues" : "Uyarılar, hatalar ve ciddi sorunlar",
    "Errors and fatal issues" : "Hatalar ve ciddi sorunlar",
    "Fatal issues only" : "Sadece ciddi sorunlar",
    "None" : "Hiçbiri",
    "Login" : "Oturum Aç",
    "Plain" : "Düz",
    "NT LAN Manager" : "NT Ağ Yöneticisi",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sistem değişkenleri sorgusuna uygun olarak ayarlanmamış görünüyor. getenv(\"PATH\") komutu sadece boş bir cevap döndürüyor.",
    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Lütfen kurulum belgelendirmesindeki php ayarlama notlarını ve sunucudaki özellikle php-fpm kullanırken php ayarlamalarını kontrol edin.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Salt Okunur yapılandırma etkinleştirilmiş. Bu, bazı ayarların web arayüzü ile yapılandırılmasını önler. Ayrıca, bu dosya her güncelleme sırasında el ile yazılabilir yapılmalıdır.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP satırıçi doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu, bazı çekirdek (core) uygulamalarını erişilemez yapacak.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu, muhtemelen Zend OPcache veya eAccelerator gibi bir önbellek/hızlandırıcı nedeniyle gerçekleşir.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Sunucunuz, Microsoft Windows ile çalışıyor. En uygun kullanıcı deneyimi için şiddetle Linux'u öneriyoruz.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "%1$s %2$s sürümünden eskisi yüklü. Kararlılık ve performans nedenleri ile daha yeni bir %1$s sürümüne güncellemenizi öneriyoruz.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modülü 'fileinfo' kayıp. MIME türü tanıma ile en iyi sonuçları elde etmek için bu modülü etkinleştirmenizi öneririz.",
    "System locale can not be set to a one which supports UTF-8." : "Sistem yereli, UTF-8 destekleyenlerden biri olarak ayarlanamadı.",
    "This means that there might be problems with certain characters in file names." : "Bu, dosya adlarında belirli karakterlerde problem olabileceği anlamına gelir.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Şu dillerden birini desteklemesi için sisteminize gerekli paketleri kurmanızı şiddetle tavsiye ederiz: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Eğer kurulumunuz alan adının köküne yapılmamışsa ve sistem cron'u kullanıyorsa, URL oluşturma ile ilgili sorunlar oluşabilir. Bu sorunların önüne geçmek için, kurulumunuzun web kök yolundaki config.php dosyasında \"overwrite.cli.url\" seçeneğini ayarlayın (Önerilen: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Bu CLI ile cronjobı çalıştırmak mümkün değildi. Aşağıdaki teknik hatalar ortaya çıkmıştır:",
    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Lütfen <a target=\"_blank\" href=\"%s\">kurulum rehberlerini ↗</a> iki kez denetleyip <a href=\"#log-section\">günlük</a> içerisindeki hata ve uyarılara bakın.",
    "Open documentation" : "Belgelendirmeyi aç",
    "Allow apps to use the Share API" : "Uygulamaların paylaşım API'sini kullanmasına izin ver",
    "Allow users to share via link" : "Kullanıcıların bağlantı ile paylaşmasına izin ver",
    "Enforce password protection" : "Parola korumasını zorla",
    "Allow public uploads" : "Herkes tarafından yüklemeye izin ver",
    "Allow users to send mail notification for shared files" : "Paylaşılmış dosyalar için kullanıcıların posta bildirimi göndermesine izin ver",
    "Set default expiration date" : "Öntanımlı son kullanma tarihini ayarla",
    "Expire after " : "Süre",
    "days" : "gün sonra dolsun",
    "Enforce expiration date" : "Son kullanma tarihini zorla",
    "Allow resharing" : "Yeniden paylaşıma izin ver",
    "Restrict users to only share with users in their groups" : "Kullanıcıların, dosyaları sadece kendi gruplarındaki kullanıcılarla paylaşmasına izin ver",
    "Allow users to send mail notification for shared files to other users" : "Kullanıcıların diğer kullanıcılara, paylaşılmış dosyalar için posta bildirimi göndermesine izin ver",
    "Exclude groups from sharing" : "Grupları paylaşma eyleminden hariç tut",
    "These groups will still be able to receive shares, but not to initiate them." : "Bu gruplar hala paylaşımları alabilecek, ancak başlatamayacaktır.",
    "Last cron job execution: %s." : "Son cron çalıştırılma: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Son cron çalıştırılma: %s. Bir şeyler yanlış gibi görünüyor.",
    "Cron was not executed yet!" : "Cron henüz çalıştırılmadı!",
    "Execute one task with each page loaded" : "Yüklenen her sayfa ile bir görev çalıştır",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php, http üzerinden her 15 dakikada bir çağrılması için webcron hizmetine kaydedilir.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Cron.php dosyasını her 15 dakikada bir çağırmak için sistem cron hizmetini kullan.",
    "Enable server-side encryption" : "Sunucu taraflı şifrelemeyi aç",
    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Şifreleme tek yönlü bir işlemdir. Şifrele etkinleştirildiğinde, yönlendirilen tüm dosyalar sunucuda şifrelenecek ve daha sonra şifrelemenin kaldırılması mümkün olmayacaktır. Bu son uyarı: Gerçekten şifrelemeyi etkinleştirmek istiyor musunuz?",
    "Enable encryption" : "Şifrelemeyi aç",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Hiç şifrelenme modülü yüklenmemiş, lütfen uygulama menüsünden bir şifreleme modülü etkinleştirin.",
    "Select default encryption module:" : "Öntanımlı şifreleme modülünü seçin:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Eski şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine taşımanız gerekli. Lütfen \"Öntanımlı şifreleme modülü\"nü etkinleştirin ve 'occ encryption:migrate' çalıştırın",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Eski şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine taşımanız gerekli.",
    "Start migration" : "Taşınmayı başlat",
    "This is used for sending out notifications." : "Bu, bildirimler gönderilirken kullanılır.",
    "Send mode" : "Gönderme kipi",
    "Encryption" : "Şifreleme",
    "From address" : "Kimden adresi",
    "mail" : "posta",
    "Authentication method" : "Kimlik doğrulama yöntemi",
    "Authentication required" : "Kimlik doğrulama gerekli",
    "Server address" : "Sunucu adresi",
    "Port" : "Port",
    "Credentials" : "Kimlik Bilgileri",
    "SMTP Username" : "SMTP Kullanıcı Adı",
    "SMTP Password" : "SMTP Parolası",
    "Store credentials" : "Kimlik bilgilerini depola",
    "Test email settings" : "E-posta ayarlarını sına",
    "Send email" : "E-posta gönder",
    "Log level" : "Günlük seviyesi",
    "Download logfile" : "Günlük dosyasını indir",
    "More" : "Daha fazla",
    "Less" : "Daha az",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Günlük dosyası 100 MB'dan daha büyük. İndirmek zaman alabilir!",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Veritabanı olarak SQLite kullanılıyor. Daha büyük kurulumlar için farklı bir veritabanı arka ucuna geçmenizi öneriyoruz.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Özellikle dosya eşitleme için masaüstü istemcisi kullanılırken SQLite kullanımı önerilmez.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Başka bir veritabanına geçmek için komut satırı aracını kullanın: 'occ db:convert-type' veya <a target=\"_blank\" href=\"%s\">belgelendirmeye ↗</a> bakın.",
    "How to do backups" : "Nasıl yedekleme yapılır",
    "Advanced monitoring" : "Gelişmiş izleme",
    "Performance tuning" : "Performans ayarlama",
    "Improving the config.php" : "config.php iyileştirme",
    "Theming" : "Tema",
    "Hardening and security guidance" : "Sağlamlaştırma ve güvenlik rehberliği",
    "Version" : "Sürüm",
    "Developer documentation" : "Geliştirici belgelendirmesi",
    "Experimental applications ahead" : "İlerideki deneysel uygulamalar",
    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Deneysel uygulamalar güvenlik açısından denetlenmemiş, yeni veya kararsız olmaya açık ya da geliştirilme aşamasında olan uygulamalardır. Yüklemek veri kaybı veya güvenlik açıklarına sebep olabilir.",
    "by" : "Yazan:",
    "licensed" : "lisanslı",
    "Documentation:" : "Belgelendirme:",
    "User Documentation" : "Kullanıcı Belgelendirmesi",
    "Admin Documentation" : "Yönetici Belgelendirmesi",
    "Show description …" : "Açıklamayı göster...",
    "Hide description …" : "Açıklamayı gizle...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu uygulama, aşağıdaki bağımlılıklar sağlanmadığından yüklenemiyor:",
    "Enable only for specific groups" : "Sadece belirli gruplar için etkinleştir",
    "Uninstall App" : "Uygulamayı Kaldır",
    "Enable experimental apps" : "Deneysel uygulamaları etkinleştir",
    "No apps found for your version" : "Sürümünüz için uygulama bulunamadı",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Merhaba,<br><br>Sadece artık bir %s hesabınızın olduğunu söylemek istedim.<br><br>Kullanıcı adınız: %s<br>Şuradan erişin: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Hoşçakalın!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Merhaba,\n\nSadece, artık bir %s hesabınızın olduğunu söylemek istedim.\n\nKullanıcı adınız: %s\nErişim: %s\n\n",
    "User documentation" : "Kullanıcı belgelendirmesi",
    "Administrator documentation" : "Yönetici belgelendirmesi",
    "Online documentation" : "Çevrimiçi belgelendirme",
    "Forum" : "Forum",
    "Issue tracker" : "Sorun izleyici",
    "Commercial support" : "Ticari destek",
    "Get the apps to sync your files" : "Dosyalarınızı eşitlemek için uygulamaları indirin",
    "Desktop client" : "Masaüstü istemcisi",
    "Android app" : "Android uygulaması",
    "iOS app" : "iOS uygulaması",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Projeyi desteklemek istiyorsanız\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">geliştirilmesine katılın</a>\n\t\tveya\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">duyurun</a>!",
    "Show First Run Wizard again" : "İlk Çalıştırma Sihirbazı'nı yeniden göster",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Kullandığınız: <strong>%s</strong>. Kullanılabilir alan: <strong>%s</strong>",
    "Password" : "Parola",
    "Unable to change your password" : "Parolanız değiştirilemiyor",
    "Current password" : "Mevcut parola",
    "New password" : "Yeni parola",
    "Change password" : "Parola değiştir",
    "Full name" : "Ad soyad",
    "No display name set" : "Ekran adı ayarlanmamış",
    "Email" : "E-posta",
    "Your email address" : "E-posta adresiniz",
    "Fill in an email address to enable password recovery and receive notifications" : "Parola kurtarmayı ve bildirim almayı açmak için bir e-posta adresi girin",
    "No email address set" : "E-posta adresi ayarlanmamış",
    "You are member of the following groups:" : "Şu grupların üyesisiniz:",
    "Profile picture" : "Profil resmi",
    "Upload new" : "Yeni yükle",
    "Select new from Files" : "Dosyalardan seç",
    "Remove image" : "Resmi kaldır",
    "Either png or jpg. Ideally square but you will be able to crop it." : "PNG veya JPG. Genellikle karedir ancak kesebileceksiniz.",
    "Your avatar is provided by your original account." : "Görüntü resminiz, özgün hesabınız tarafından sağlanıyor.",
    "Cancel" : "İptal",
    "Choose as profile image" : "Profil resmi olarak seç",
    "Language" : "Dil",
    "Help translate" : "Çevirilere yardım edin",
    "Common Name" : "Ortak Ad",
    "Valid until" : "Geçerlilik",
    "Issued By" : "Veren",
    "Valid until %s" : "%s tarihine kadar geçerli",
    "Import root certificate" : "Kök sertifikalarını içe aktar",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "{communityopen}ownCloud topluluğu tarafından{linkclose} geliştirildi. {githubopen}Kaynak kodu{linkclose}, {licenseopen}<abbr title=\"Affero Genel Kamu Lisansı\">AGPL</abbr>{linkclose} ile lisanslanmıştır.",
    "Show storage location" : "Depolama konumunu göster",
    "Show last log in" : "Son oturum açılma zamanını göster",
    "Show user backend" : "Kullanıcı arka ucunu göster",
    "Send email to new user" : "Yeni kullanıcıya e-posta gönder",
    "Show email address" : "E-posta adresini göster",
    "Username" : "Kullanıcı Adı",
    "E-Mail" : "E-Posta",
    "Create" : "Oluştur",
    "Admin Recovery Password" : "Yönetici Kurtarma Parolası",
    "Enter the recovery password in order to recover the users files during password change" : "Parola değiştirme sırasında kullanıcı dosyalarını kurtarmak için kurtarma parolasını girin",
    "Search Users" : "Kullanıcı Ara",
    "Add Group" : "Grup Ekle",
    "Group" : "Grup",
    "Everyone" : "Herkes",
    "Admins" : "Yöneticiler",
    "Default Quota" : "Öntanımlı Kota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Lütfen disk alanı kotasını girin (örnek: \"512MB\" veya \"12GB\")",
    "Unlimited" : "Sınırsız",
    "Other" : "Diğer",
    "Full Name" : "Tam Adı",
    "Group Admin for" : "Grup Yöneticisi",
    "Quota" : "Kota",
    "Storage Location" : "Depolama Konumu",
    "User Backend" : "Kullanıcı Arka Ucu",
    "Last Login" : "Son Giriş",
    "change full name" : "tam adı değiştir",
    "set new password" : "yeni parola belirle",
    "change email address" : "e-posta adresini değiştir",
    "Default" : "Öntanımlı"
},
"nplurals=2; plural=(n > 1);");
